Module session

Module session 

Session — the primary read scope for all database access.

Sessions are cheap, synchronous, and infallible to create. All reads go through sessions, and sessions are the factory for transactions (writes).

Structs

Params
Facade for session-scoped parameters.
QueryBuilder
Builder for parameterized queries within a session.
Session
A database session — the primary scope for reads.
SessionCapabilities
Describes the capabilities of a session in its current mode.
SessionMetrics
Snapshot of session-level metrics.
TransactionBuilder
Builder for starting a transaction with options.

Enums

WriteLeaseSummary
Summary of the write lease strategy, suitable for capability snapshots.