pub struct TransactionSync<'a> { /* private fields */ }Implementations
Sourceimpl<'a> TransactionSync<'a>
impl<'a> TransactionSync<'a>
pub fn query(&self, cypher: &str) -> Result<QueryResult>
Sourcepub fn query_with<'t>(&'t self, cypher: &str) -> TxQueryBuilderSync<'t, 'a>
pub fn query_with<'t>(&'t self, cypher: &str) -> TxQueryBuilderSync<'t, 'a>
Execute a Cypher query with parameters using a builder.
pub fn execute(&self, cypher: &str) -> Result<ExecuteResult>
Sourcepub fn execute_with<'t>(&'t self, cypher: &str) -> ExecuteBuilderSync<'t, 'a>
pub fn execute_with<'t>(&'t self, cypher: &str) -> ExecuteBuilderSync<'t, 'a>
Execute a mutation with parameters using a builder.
Sourcepub fn locy(&self, program: &str) -> Result<LocyResult>
pub fn locy(&self, program: &str) -> Result<LocyResult>
Evaluate a Locy program within the transaction.
Sourcepub fn locy_with<'t>(&'t self, program: &str) -> TxLocyBuilderSync<'t, 'a>
pub fn locy_with<'t>(&'t self, program: &str) -> TxLocyBuilderSync<'t, 'a>
Evaluate a Locy program with parameters using a builder.
Sourcepub fn apply(&self, derived: DerivedFactSet) -> Result<ApplyResult>
pub fn apply(&self, derived: DerivedFactSet) -> Result<ApplyResult>
Apply a DerivedFactSet to this transaction.
Sourcepub fn apply_with(&self, derived: DerivedFactSet) -> ApplyBuilderSync<'_, 'a>
pub fn apply_with(&self, derived: DerivedFactSet) -> ApplyBuilderSync<'_, 'a>
Apply a DerivedFactSet with staleness controls.
Sourcepub fn prepare(&self, cypher: &str) -> Result<PreparedQuery>
pub fn prepare(&self, cypher: &str) -> Result<PreparedQuery>
Prepare a Cypher query for repeated execution.
Sourcepub fn prepare_locy(&self, program: &str) -> Result<PreparedLocy>
pub fn prepare_locy(&self, program: &str) -> Result<PreparedLocy>
Prepare a Locy program for repeated evaluation.
pub fn commit(self) -> Result<CommitResult>
pub fn rollback(self)
Sourcepub fn bulk_writer(&self) -> BulkWriterBuilder
pub fn bulk_writer(&self) -> BulkWriterBuilder
Create a bulk writer builder for efficient data loading.
Sourcepub fn appender(&self, label: &str) -> AppenderBuilder
pub fn appender(&self, label: &str) -> AppenderBuilder
Create a streaming appender for row-by-row data loading.
Sourcepub fn bulk_insert_vertices(
&self,
label: &str,
properties_list: Vec<Properties>,
) -> Result<Vec<Vid>>
pub fn bulk_insert_vertices( &self, label: &str, properties_list: Vec<Properties>, ) -> Result<Vec<Vid>>
Bulk insert vertices within this transaction.
Sourcepub fn bulk_insert_edges(
&self,
edge_type: &str,
edges: Vec<(Vid, Vid, Properties)>,
) -> Result<()>
pub fn bulk_insert_edges( &self, edge_type: &str, edges: Vec<(Vid, Vid, Properties)>, ) -> Result<()>
Bulk insert edges within this transaction.