pub fn parse_duration_from_value(val: &Value) -> Result<CypherDuration, Error>Expand description
Parse a duration from a Value, handling temporal durations, ISO 8601 strings, and integer microseconds.
pub fn parse_duration_from_value(val: &Value) -> Result<CypherDuration, Error>Parse a duration from a Value, handling temporal durations, ISO 8601 strings, and integer microseconds.