new_create_exec

Function new_create_exec 

pub fn new_create_exec(
    input: Arc<dyn ExecutionPlan>,
    pattern: Pattern,
    mutation_ctx: Arc<MutationContext>,
) -> MutationExec
Create a new MutationExec configured for a CREATE clause.

Computes an extended output schema that includes LargeBinary cv_encoded columns for any variables introduced by the pattern that are not already in the input schema.