create_startnode_udf

Function create_startnode_udf 

pub fn create_startnode_udf() -> ScalarUDF
Create the startnode UDF for getting the start node of a relationship.

At translation time, all known node variable columns are appended as extra arguments so the UDF can find the matching node by VID at runtime.