Module custom_functions

Module custom_functions 

User-defined scalar function registry.

Custom scalar functions can be registered at the database level and are available in both the DataFusion columnar execution path and the direct expression evaluator.

Structs

CustomFunctionRegistry
Registry of user-defined scalar functions.

Type Aliases

CustomScalarFn
Type alias for a custom scalar function.