Module runtime

Module runtime 

Modules

context
id_allocator
ID allocation for vertices and edges using pure auto-increment counters.
l0
l0_manager
l0_visibility
L0 Visibility Chain Abstraction
property_manager
vid_remapper
Bidirectional mapping between sparse VIDs and dense array indices.
wal
working_graph
writer

Structs

EdgeData
Edge data - TOPOLOGY ONLY
EidRemapper
Bidirectional mapping between sparse EIDs and dense array indices.
L0Buffer
L0Manager
PropertyManager
QueryContext
SimpleGraph
Simple directed graph with adjacency lists.
VertexData
Vertex data - TOPOLOGY ONLY
VidRemapper
Bidirectional mapping between sparse Vid and dense array indices.
WriteAheadLog
Writer

Enums

Direction
Direction for neighbor traversal.

Type Aliases

WorkingGraph