pub struct IndexRebuildManager { /* private fields */ }Expand description
Manages background index rebuilding with status tracking and retry logic.
The manager maintains a queue of index rebuild tasks and processes them
in the background. Tasks can be monitored via status() and retried
via retry_failed().
Implementations
Sourceimpl IndexRebuildManager
impl IndexRebuildManager
Sourcepub async fn new(
storage: Arc<StorageManager>,
schema_manager: Arc<SchemaManager>,
config: IndexRebuildConfig,
) -> Result<IndexRebuildManager, Error>
pub async fn new( storage: Arc<StorageManager>, schema_manager: Arc<SchemaManager>, config: IndexRebuildConfig, ) -> Result<IndexRebuildManager, Error>
Create a new IndexRebuildManager.
Sourcepub async fn schedule(&self, labels: Vec<String>) -> Result<Vec<String>, Error>
pub async fn schedule(&self, labels: Vec<String>) -> Result<Vec<String>, Error>
Schedule labels for background index rebuild.
Returns the task IDs for the scheduled rebuilds.
Sourcepub fn status(&self) -> Vec<IndexRebuildTask>
pub fn status(&self) -> Vec<IndexRebuildTask>
Get status of all tasks.
Sourcepub fn task_status(&self, task_id: &str) -> Option<IndexRebuildTask>
pub fn task_status(&self, task_id: &str) -> Option<IndexRebuildTask>
Get status of a specific task by ID.
Sourcepub fn is_index_building(&self, label: &str) -> bool
pub fn is_index_building(&self, label: &str) -> bool
Check if a label has a pending or in-progress index rebuild.
Sourcepub async fn cleanup_completed(&self) -> Result<usize, Error>
pub async fn cleanup_completed(&self) -> Result<usize, Error>
Remove completed/failed tasks from tracking.
Sourcepub fn start_background_worker(
self: Arc<IndexRebuildManager>,
shutdown_rx: Receiver<()>,
) -> JoinHandle<()>
pub fn start_background_worker( self: Arc<IndexRebuildManager>, shutdown_rx: Receiver<()>, ) -> JoinHandle<()>
Start background worker that processes pending tasks.
This spawns a tokio task that periodically checks for pending tasks and processes them.