Session — the primary read scope for all database access.
Sessions are cheap, synchronous, and infallible to create. All reads go through sessions, and sessions are the factory for transactions (writes).
Structs
- Params
- Facade for session-scoped parameters.
- Query
Builder - Builder for parameterized queries within a session.
- Session
- A database session — the primary scope for reads.
- Session
Capabilities - Describes the capabilities of a session in its current mode.
- Session
Metrics - Snapshot of session-level metrics.
- Transaction
Builder - Builder for starting a transaction with options.
Enums
- Write
Lease Summary - Summary of the write lease strategy, suitable for capability snapshots.