User-defined scalar function registry.
Custom scalar functions can be registered at the database level and are available in both the DataFusion columnar execution path and the direct expression evaluator.
Structs
- Custom
Function Registry - Registry of user-defined scalar functions.
Type Aliases
- Custom
Scalar Fn - Type alias for a custom scalar function.