Modules
- context
- id_
allocator - ID allocation for vertices and edges using pure auto-increment counters.
- l0
- l0_
manager - l0_
visibility - L0 Visibility Chain Abstraction
- property_
manager - vid_
remapper - Bidirectional mapping between sparse VIDs and dense array indices.
- wal
- working_
graph - writer
Structs
- Edge
Data - Edge data - TOPOLOGY ONLY
- EidRemapper
- Bidirectional mapping between sparse EIDs and dense array indices.
- L0Buffer
- L0Manager
- Property
Manager - Query
Context - Simple
Graph - Simple directed graph with adjacency lists.
- Vertex
Data - Vertex data - TOPOLOGY ONLY
- VidRemapper
- Bidirectional mapping between sparse Vid and dense array indices.
- Write
Ahead Log - Writer
Enums
- Direction
- Direction for neighbor traversal.